<div align=center>
  
  # doomsday-clock v0.1.3
  
  **A package to get the current doomsday-clock time.**
</div>

## +Info and usage:
go to the wiki on the Github Page.

## +Install:
**manually**
- Download project
- cd in the project dir with the console
- run: `pip install . --upgrade`
- your done!

**install with pip**
- run: `pip install doomsday-clock-status`
- your done!


### author:
@cookie0o on github
